==> hwde_0.61.zip: hwde/doc/hwde.R <==
###################################################
### chunk number 1: 
###################################################
options(show.signif.stars=FALSE)


###################################################
### chunk number 2: 
###################################################
obs <- c(AA=147, Aa=78, aa=17)
oset <- c(0, log(2), 0)
ma <- c(0,1,2)
hw.glm <- glm(obs ~ ma, family=poisson, offset=oset)
summary(hw.glm)


###################################################
### chunk number 3: 
###################################################
hwdat <- data.frame(Observed=c(147,78,17), locus1=c("AA","Aa","aa"))


###################################################
### chunk number 4: 
###################################################
library(hwde)
hwde(data=hwdat)


###################################################
### chunk number 5: maa
###################################################
data.df <- hwde(data = hwdat)$data.df
names(data.df)
summary(glm(obs ~ a + aa, offset=oset, family=poisson, data=data.df))$coef


###################################################
### chunk number 6:  eval=FALSE
###################################################
## hwde(data=mendelABC, loci=c("seedshape","cotylcolor","coatcolor"))


###################################################
### chunk number 7:  eval=FALSE
###################################################
## hwdat <- read.table("hw.txt", header=TRUE)


###################################################
### chunk number 8:  eval=FALSE
###################################################
## IndianIrish <- read.table("IndianIrish.txt", header=TRUE)


###################################################
### chunk number 9: 
###################################################
hwde(data=IndianIrish)


###################################################
### chunk number 10:  eval=FALSE
###################################################
## hwde(data=IndianIrish, group.terms=FALSE)


###################################################
### chunk number 11: all9
###################################################
II.hwde <- hwde(data = mendelABC, loci = c("seedshape", "cotylcolor", 
              "coatcolor"), keep.models=T)
models <- II.hwde$models
maxmodel <- models[[length(models)]]
summary(maxmodel)$coef


###################################################
### chunk number 12: 
###################################################
hwdat.hw <- hwde(data=hwdat)
names(hwdat)
hwdat.hw$data.df


###################################################
### chunk number 13: 
###################################################
data.df <- hwdat.hw$data.df
model1 <- glm(obs ~ a, family=poisson, data=data.df, offset=log(oset))
model2 <- glm(obs ~ a+aa, family=poisson, data=data.df, offset=log(oset))
model1


###################################################
### chunk number 14: 
###################################################
II.hw <- hwde(data=IndianIrish, aovtable.print=FALSE)
dataII.df <- II.hw$data.df
dataII.df


###################################################
### chunk number 15: 
###################################################
hwde(termlist=c("+a","+aa"), refmodel=c(1,2), data=hwdat)


###################################################
### chunk number 16: 
###################################################
hwde(termlist=c("+gp","+a","+b","+a+b","+aa"), refmodel=c(1,2,2,2,5), 
     data=IndianIrish)


###################################################
### chunk number 17: 
###################################################
hwdat.hw <- hwde(data=hwdat, keep.models=TRUE)
hwdat.hw$models[[2]]          # The Hardy-Weinberg model
fitted(hwdat.hw$models[[2]])

==> hwde_0.62.zip: hwde/doc/hwde.R <==
###################################################
### chunk number 1: 
###################################################
#line 39 "d:/Rcompile/CRANpkg/local/2.12/hwde/inst/doc/hwde.Rnw"
options(show.signif.stars=FALSE)


###################################################
### chunk number 2: 
###################################################
#line 42 "d:/Rcompile/CRANpkg/local/2.12/hwde/inst/doc/hwde.Rnw"
obs <- c(AA=147, Aa=78, aa=17)
oset <- c(0, log(2), 0)
ma <- c(0,1,2)
hw.glm <- glm(obs ~ ma, family=poisson, offset=oset)
summary(hw.glm)


###################################################
### chunk number 3: 
###################################################
#line 53 "d:/Rcompile/CRANpkg/local/2.12/hwde/inst/doc/hwde.Rnw"
hwdat <- data.frame(Observed=c(147,78,17), locus1=c("AA","Aa","aa"))


###################################################
### chunk number 4: 
###################################################
#line 57 "d:/Rcompile/CRANpkg/local/2.12/hwde/inst/doc/hwde.Rnw"
library(hwde)
hwde(data=hwdat)


###################################################
### chunk number 5: maa
###################################################
#line 71 "d:/Rcompile/CRANpkg/local/2.12/hwde/inst/doc/hwde.Rnw"
data.df <- hwde(data = hwdat)$data.df
names(data.df)
summary(glm(obs ~ a + aa, offset=oset, family=poisson, data=data.df))$coef


###################################################
### chunk number 6:  eval=FALSE
###################################################
## #line 123 "d:/Rcompile/CRANpkg/local/2.12/hwde/inst/doc/hwde.Rnw"
## hwde(data=mendelABC, loci=c("seedshape","cotylcolor","coatcolor"))


###################################################
### chunk number 7:  eval=FALSE
###################################################
## #line 147 "d:/Rcompile/CRANpkg/local/2.12/hwde/inst/doc/hwde.Rnw"
## hwdat <- read.table("hw.txt", header=TRUE)


###################################################
### chunk number 8:  eval=FALSE
###################################################
## #line 189 "d:/Rcompile/CRANpkg/local/2.12/hwde/inst/doc/hwde.Rnw"
## IndianIrish <- read.table("IndianIrish.txt", header=TRUE)


###################################################
### chunk number 9: 
###################################################
#line 192 "d:/Rcompile/CRANpkg/local/2.12/hwde/inst/doc/hwde.Rnw"
hwde(data=IndianIrish)


###################################################
### chunk number 10:  eval=FALSE
###################################################
## #line 201 "d:/Rcompile/CRANpkg/local/2.12/hwde/inst/doc/hwde.Rnw"
## hwde(data=IndianIrish, group.terms=FALSE)


###################################################
### chunk number 11: all9
###################################################
#line 210 "d:/Rcompile/CRANpkg/local/2.12/hwde/inst/doc/hwde.Rnw"
II.hwde <- hwde(data = mendelABC, loci = c("seedshape", "cotylcolor", 
              "coatcolor"), keep.models=T)
models <- II.hwde$models
maxmodel <- models[[length(models)]]
summary(maxmodel)$coef


###################################################
### chunk number 12: 
###################################################
#line 223 "d:/Rcompile/CRANpkg/local/2.12/hwde/inst/doc/hwde.Rnw"
hwdat.hw <- hwde(data=hwdat)
names(hwdat)
hwdat.hw$data.df


###################################################
### chunk number 13: 
###################################################
#line 231 "d:/Rcompile/CRANpkg/local/2.12/hwde/inst/doc/hwde.Rnw"
data.df <- hwdat.hw$data.df
model1 <- glm(obs ~ a, family=poisson, data=data.df, offset=log(oset))
model2 <- glm(obs ~ a+aa, family=poisson, data=data.df, offset=log(oset))
model1


###################################################
### chunk number 14: 
###################################################
#line 239 "d:/Rcompile/CRANpkg/local/2.12/hwde/inst/doc/hwde.Rnw"
II.hw <- hwde(data=IndianIrish, aovtable.print=FALSE)
dataII.df <- II.hw$data.df
dataII.df


###################################################
### chunk number 15: 
###################################################
#line 251 "d:/Rcompile/CRANpkg/local/2.12/hwde/inst/doc/hwde.Rnw"
hwde(termlist=c("+a","+aa"), refmodel=c(1,2), data=hwdat)


###################################################
### chunk number 16: 
###################################################
#line 258 "d:/Rcompile/CRANpkg/local/2.12/hwde/inst/doc/hwde.Rnw"
hwde(termlist=c("+gp","+a","+b","+a+b","+aa"), refmodel=c(1,2,2,2,5), 
     data=IndianIrish)


###################################################
### chunk number 17: 
###################################################
#line 268 "d:/Rcompile/CRANpkg/local/2.12/hwde/inst/doc/hwde.Rnw"
hwdat.hw <- hwde(data=hwdat, keep.models=TRUE)
hwdat.hw$models[[2]]          # The Hardy-Weinberg model
fitted(hwdat.hw$models[[2]])
